API Reference
===============

.. warning::

    Private functions are not meant to be used out of context, and doing so may lead to unexpected results.

rnalysis.filtering module
-------------------------

.. automodule:: rnalysis.filtering
   :private-members:
   :noindex:
   :show-inheritance:
   :inherited-members:

rnalysis.enrichment module
--------------------------

.. automodule:: rnalysis.enrichment
   :members:
   :private-members:
   :noindex:
   :show-inheritance:
   :inherited-members:

rnalysis.general module
-----------------------

.. automodule:: rnalysis.general
   :private-members:
   :noindex:
   :show-inheritance:
   :inherited-members:

rnalysis.utils module
-----------------------

.. automodule:: rnalysis.utils
   :private-members:
   :noindex:
   :show-inheritance:
   :inherited-members:
